/**
 * 判断url是否是http或https
 * @param {string} path
 * @returns {Boolean}
 */
export function isHttp(url) {
  return url.indexOf('http://') !== -1 || url.indexOf('https://') !== -1;
}

/**
 * 判断path是否为外链
 * @param {string} path
 * @returns {Boolean}
 */
export function isExternal(path) {
  return /^(https?:|mailto:|tel:)/.test(path);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUsername(str) {
  const valid_map = ['admin', 'editor'];
  return valid_map.indexOf(str.trim()) >= 0;
}

/**
 * @param {string} url
 * @returns {Boolean}
 */
export function isURL(url) {
  const reg =
    /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/;
  return reg.test(url);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validLowerCase(str) {
  const reg = /^[a-z]+$/;
  return reg.test(str);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUpperCase(str) {
  const reg = /^[A-Z]+$/;
  return reg.test(str);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validAlphabets(str) {
  const reg = /^[A-Za-z]+$/;
  return reg.test(str);
}

/**
 * @param {string} email
 * @returns {Boolean}
 */
export function isEmail(email) {
  const reg = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
  return reg.test(email);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function isString(str) {
  if (typeof str === 'string' || str instanceof String) {
    return true;
  }
  return false;
}

export function isPhone(str) {
  return str && /^1[3456789]\d{9}$/.test(str)
}

/**
 * @param {Array} arg
 * @returns {Boolean}
 */
export function isArray(arg) {
  if (typeof Array.isArray === 'undefined') {
    return Object.prototype.toString.call(arg) === '[object Array]';
  }
  return Array.isArray(arg);
}

// 是否纯英文
export function isAllEN(val) {
  return /^[a-zA-Z]*$/.test(val);
}

// 是否纯中文
export function isAllCN(val) {
  return /^[\u4E00-\u9FA5]*$/.test(val);
}

// 校验手机号
export function validPhone(rule, value, callback) {
  if (value && !/^1[3456789]\d{9}$/.test(value)) {
    return callback(new Error('请输入正确的11位号码'));
  } else {
    return callback();
  }
}

// 校验固话和手机号
export function validPhoneAndMobile(rule, value, callback) {
  if (value && !/^((0\d{2,3}-?\d{7,8})|(1[3465789]\d{9}))$/.test(value)) {
    return callback(new Error('请输入正确的电话号码'));
  } else {
    return callback();
  }
}

// 校验邮箱
export function validEmail(rule, value, callback) {
  if (value && !isEmail(value)) {
    return callback(new Error('请输入正确的邮箱'));
  } else {
    return callback();
  }
}

// 校验纳税人识别号
export function validTaxpayer(rule, value, callback) {
  if (value && !/^[A-Z0-9]{15}$|^[A-Z0-9]{18}$|^[A-Z0-9]{20}$/.test(value)) {
    return callback(new Error('请输入正确的纳税人识别号'));
  } else {
    return callback();
  }
}

// 校验是否网站
export function validUrl(rule, value, callback) {
  if (value && !isURL(value)) {
    return callback(new Error('请输入正确的网站'));
  } else {
    return callback();
  }
}

// 校验银行卡
export function validBankCard(rule, value, callback) {
  const strBin = '10,18,30,35,37,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,58,60,62,65,68,69,84,87,88,94,95,98,99';
  if (!value) {
    return callback();
  } else if (!Number.isInteger(+value)) {
    callback(new Error('银行卡号必须全为数字'));
  } else if (value.trim().length < 8 || value.trim().length > 32) {
    callback(new Error('银行卡号长度必须在8到32之间'));
  } else {
    callback();
  }
}
